@@ -112,8 +112,8 @@ offsetX <- function(y, x=rep(1, length(y)), width=0.4, varwidth=FALSE,...) {
 #' \describe{
 #'   \item{quasirandom:}{points are distributed within a kernel density estimate of the distribution with offset determined by quasirandom Van der Corput noise}
 #'   \item{pseudorandom:}{points are distributed within a kernel density estimate of the distribution with offset determined by pseudorandom noise a la jitter}
-#'   \item{smiley:}{points are distributed within a kernel density with points in a band distributed with highest value points on the  outside and lowest in the middle}
-#'   \item{frowney:}{points are distributed within a kernel density with points in a band distributed with highest value points in the middle and lowest on the outside}
+#'   \item{maxout:}{points are distributed within a kernel density with points in a band distributed with highest value points on the  outside and lowest in the middle}
+#'   \item{minout:}{points are distributed within a kernel density with points in a band distributed with highest value points in the middle and lowest on the outside}
 #'   \item{tukey:}{points are distributed as described in Tukey and Tukey "Strips displaying empirical distributions: I. textured dot strips"}
 #'   \item{tukeyDense:}{points are distributed as described in Tukey and Tukey but are constrained with the kernel density estimate}
 #' }
@@ -123,8 +123,10 @@ offsetX <- function(y, x=rep(1, length(y)), width=0.4, varwidth=FALSE,...) {
 #' @rdname offsetX 
 # @seealso \code{\link{offsetX}}, \code{\link[stats]{density}}
 # @return a vector with of x-offsets between -1 and 1 of the same length as y
-offsetSingleGroup<-function(y,maxLength=NULL,method=c('quasirandom','pseudorandom','smiley','frowney','tukey','tukeyDense'),nbins=NULL,adjust=1) {
+offsetSingleGroup<-function(y,maxLength=NULL,method=c('quasirandom','pseudorandom','smiley','maxout','frowney','minout','tukey','tukeyDense'),nbins=NULL,adjust=1) {
   method<-match.arg(method)
+  if(method %in% c('smiley'))method<-'maxout' 
+  if(method %in% c('frowney'))method<-'minout' 
   if(is.null(nbins))nbins<-ifelse(method %in% c("pseudorandom","quasirandom"),2^10,ceiling(length(y)/5))
   #catch 0 length inputs
   if (length(y) == 0) return(NULL)
@@ -140,8 +142,8 @@ offsetSingleGroup<-function(y,maxLength=NULL,method=c('quasirandom','pseudorando
   offset <- switch(method,
     'quasirandom'=vanDerCorput(length(y))[rank(y, ties.method="first")],
     'pseudorandom'=stats::runif(length(y)),
-    'smiley'=stats::ave(y,as.character(cut(y,dens$x)),FUN=topBottomDistribute),
-    'frowney'=stats::ave(y,as.character(cut(y,dens$x)),FUN=function(x)topBottomDistribute(x,frowney=TRUE)),
+    'maxout'=stats::ave(y,as.character(cut(y,dens$x)),FUN=topBottomDistribute),
+    'minout'=stats::ave(y,as.character(cut(y,dens$x)),FUN=function(x)topBottomDistribute(x,frowney=TRUE)),
     'tukeyDense'=tukeyTexture(y)/100,
     'tukey'=tukeyTexture(y,TRUE,TRUE)/100,
     stop(simpleError('Unrecognized method in offsetSingleGroup'))
