@@ -37,10 +37,10 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
 ##     offsets <- list(
 ##       'Quasi'=offsetX(y),  # Default
 ##       'Pseudo'=offsetX(y, method='pseudorandom',nbins=100),
-##       'Frown'=offsetX(y, method='frowney',nbins=20),
-##       'Smile\n20 bin'=offsetX(y, method='smiley',nbins=20),
-##       'Smile\n100 bin'=offsetX(y, method='smiley',nbins=100),
-##       'Smile\nn/5 bin'=offsetX(y, method='smiley',nbins=round(length(y)/5)),
+##       'Min out'=offsetX(y, method='minout',nbins=20),
+##       'Max out\n20 bin'=offsetX(y, method='maxout',nbins=20),
+##       'Max out\n100 bin'=offsetX(y, method='maxout',nbins=100),
+##       'Max out\nn/5 bin'=offsetX(y, method='maxout',nbins=round(length(y)/5)),
 ##       'Beeswarm'=swarmx(rep(0,length(y)),y)$x,
 ##       'Tukey'=offsetX(y,method='tukey'),
 ##       'Tukey +\ndensity'=offsetX(y,method='tukeyDense')
@@ -49,7 +49,8 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
 ##     points(unlist(offsets) + ids, rep(y, length(offsets)),
 ##           pch=21,col='#00000099',bg='#00000033')
 ##   par(lheight=.8)
-##   axis(1, 1:length(offsets), names(offsets),padj=1,mgp=c(0,-.3,0),tcl=-.5)
+##   axis(1, 1:length(offsets), names(offsets),padj=1,
+##     mgp=c(0,-.1,0),tcl=-.5,cex.axis=1.1)
 ## })
 
 
@@ -67,10 +68,10 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
     offsets <- list(
       'Quasi'=offsetX(y),  # Default
       'Pseudo'=offsetX(y, method='pseudorandom',nbins=100),
-      'Frown'=offsetX(y, method='frowney',nbins=20),
-      'Smile\n20 bin'=offsetX(y, method='smiley',nbins=20),
-      'Smile\n100 bin'=offsetX(y, method='smiley',nbins=100),
-      'Smile\nn/5 bin'=offsetX(y, method='smiley',nbins=round(length(y)/5)),
+      'Min out'=offsetX(y, method='minout',nbins=20),
+      'Max out\n20 bin'=offsetX(y, method='maxout',nbins=20),
+      'Max out\n100 bin'=offsetX(y, method='maxout',nbins=100),
+      'Max out\nn/5 bin'=offsetX(y, method='maxout',nbins=round(length(y)/5)),
       'Beeswarm'=swarmx(rep(0,length(y)),y)$x,
       'Tukey'=offsetX(y,method='tukey'),
       'Tukey +\ndensity'=offsetX(y,method='tukeyDense')
@@ -79,7 +80,8 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
     points(unlist(offsets) + ids, rep(y, length(offsets)),
           pch=21,col='#00000099',bg='#00000033')
   par(lheight=.8)
-  axis(1, 1:length(offsets), names(offsets),padj=1,mgp=c(0,-.3,0),tcl=-.5)
+  axis(1, 1:length(offsets), names(offsets),padj=1,
+    mgp=c(0,-.1,0),tcl=-.5,cex.axis=1.1)
 })
 
 
@@ -126,10 +128,10 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
   offsets <- list(
     'Quasi'=offsetX(y),  # Default
     'Pseudo'=offsetX(y, method='pseudorandom',nbins=100),
-    'Frown'=offsetX(y, method='frowney',nbins=20),
-    'Smile\n20 bin'=offsetX(y, method='smiley',nbins=20),
-    'Smile\n100 bin'=offsetX(y, method='smiley',nbins=100),
-    'Smile\nn/5 bin'=offsetX(y, method='smiley',nbins=round(length(y)/5)),
+    'Min out'=offsetX(y, method='minout',nbins=20),
+    'Max out\n20 bin'=offsetX(y, method='maxout',nbins=20),
+    'Max out\n100 bin'=offsetX(y, method='maxout',nbins=100),
+    'Max out\nn/5 bin'=offsetX(y, method='maxout',nbins=round(length(y)/5)),
     'Beeswarm'=swarmx(rep(0,length(y)),y)$x,
     'Tukey'=offsetX(y,method='tukey'),
     'Tukey +\ndensity'=offsetX(y,method='tukeyDense')
@@ -139,16 +141,18 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
   #reduce file size by rendering to raster
   tmpPng<-tempfile(fileext='.png')
   png(tmpPng,height=1200,width=1800,res=300)
-  par(mar=c(2.5,4,.2,0.2))
-  plot(unlist(offsets) + ids, rep(y, length(offsets)),
-    xlab='', xaxt='n', yaxt='n',pch=21,
-    ylab='Land area (square miles)', col='#00000033',
-    bg='#00000011',cex=.3,mgp=c(3.2,1,0))
+  par(mar=c(2.5,3.5,.2,0.2))
+  plot(
+    unlist(offsets) + ids, rep(y, length(offsets)),
+    xlab='', xaxt='n', yaxt='n',pch='.',
+    ylab='Land area (square miles)',mgp=c(2.7,1,0),
+    col='#00000077'
+  )
   par(lheight=.8)
   axis(1, 1:length(offsets), names(offsets),padj=1,
-    mgp=c(0,-.3,0),tcl=-.3,cex.axis=.7)
+    mgp=c(0,-.3,0),tcl=-.3,cex.axis=.65)
   axis(2, pretty(y), format(10^pretty(y),scientific=FALSE,big.mark=','),
-    mgp=c(0,.6,0),tcl=-.3,las=1,cex.axis=.75)
+    mgp=c(0,.5,0),tcl=-.3,las=1,cex.axis=.75)
   dev.off()
 
 
@@ -181,8 +185,8 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
 ##   title(main='Pseudorandom')
 ##   #smiley
 ##   plotFunc(OrchardSprays$treatment,log(OrchardSprays$decrease),
-##     list(method='smiley',width=.2))
-##   title(main='Smiley')
+##     list(method='maxout',width=.2))
+##   title(main='Max outside')
 ##   #beeswarm
 ##   beeInput<-split(log(OrchardSprays$decrease), OrchardSprays$treatment)
 ##   beeswarm(beeInput,las=1,ylab='Log treatment effect',xlab='Treatment',
@@ -222,8 +226,8 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
   title(main='Pseudorandom')
   #smiley
   plotFunc(OrchardSprays$treatment,log(OrchardSprays$decrease),
-    list(method='smiley',width=.2))
-  title(main='Smiley')
+    list(method='maxout',width=.2))
+  title(main='Max outside')
   #beeswarm
   beeInput<-split(log(OrchardSprays$decrease), OrchardSprays$treatment)
   beeswarm(beeInput,las=1,ylab='Log treatment effect',xlab='Treatment',
@@ -253,8 +257,8 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
 ##   plotFunc(parts,singer$height,offsetXArgs=list(method='pseudo'),
 ##     main='Pseudorandom')
 ##   #smiley
-##   plotFunc(parts,singer$height,offsetXArgs=list(method='smiley'),
-##     main='Smiley')
+##   plotFunc(parts,singer$height,offsetXArgs=list(method='maxout'),
+##     main='Max outside')
 ##   #beeswarm
 ##   beeInput<-split(singer$height, parts)
 ##   beeswarm(beeInput,ylab='Height',main='Beeswarm',
@@ -284,8 +288,8 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
   plotFunc(parts,singer$height,offsetXArgs=list(method='pseudo'),
     main='Pseudorandom')
   #smiley
-  plotFunc(parts,singer$height,offsetXArgs=list(method='smiley'),
-    main='Smiley')
+  plotFunc(parts,singer$height,offsetXArgs=list(method='maxout'),
+    main='Max outside')
   #beeswarm
   beeInput<-split(singer$height, parts)
   beeswarm(beeInput,ylab='Height',main='Beeswarm',
@@ -314,7 +318,7 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
 ##   #pseudorandom
 ##   plotFunc(x,y,offsetXArgs=list(method='pseudo'),main='Pseudorandom')
 ##   #smiley
-##   plotFunc(x,y,offsetXArgs=list(method='smiley'),main='Smiley')
+##   plotFunc(x,y,offsetXArgs=list(method='maxout'),main='Max outside')
 ##   #beeswarm
 ##   beeInput<-split(y,x)
 ##   beeswarm(beeInput,las=1,ylab='Body temperature',main='Beeswarm',
@@ -342,7 +346,7 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
   #pseudorandom
   plotFunc(x,y,offsetXArgs=list(method='pseudo'),main='Pseudorandom')
   #smiley
-  plotFunc(x,y,offsetXArgs=list(method='smiley'),main='Smiley')
+  plotFunc(x,y,offsetXArgs=list(method='maxout'),main='Max outside')
   #beeswarm
   beeInput<-split(y,x)
   beeswarm(beeInput,las=1,ylab='Body temperature',main='Beeswarm',
@@ -371,7 +375,7 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
 ##   #pseudorandom
 ##   plotFunc(x,y,offsetXArgs=list(method='pseudo'),main='Pseudorandom')
 ##   #smiley
-##   plotFunc(x,y,offsetXArgs=list(method='smiley'),main='Smiley')
+##   plotFunc(x,y,offsetXArgs=list(method='maxout'),main='Max outside')
 ##   #beeswarm
 ##   #beeInput<-split(y,x)
 ##   beeswarm(EuStockMarkets[,'DAX',drop=FALSE],cex=.7, ylab='Price',
@@ -399,7 +403,7 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
   #pseudorandom
   plotFunc(x,y,offsetXArgs=list(method='pseudo'),main='Pseudorandom')
   #smiley
-  plotFunc(x,y,offsetXArgs=list(method='smiley'),main='Smiley')
+  plotFunc(x,y,offsetXArgs=list(method='maxout'),main='Max outside')
   #beeswarm
   #beeInput<-split(y,x)
   beeswarm(EuStockMarkets[,'DAX',drop=FALSE],cex=.7, ylab='Price',
@@ -435,7 +439,7 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
   #pseudorandom
   plotFunc(x,y,offsetXArgs=list(method='pseudo'),main='Pseudorandom')
   #smiley
-  plotFunc(x,y,offsetXArgs=list(method='smiley'),main='Smiley')
+  plotFunc(x,y,offsetXArgs=list(method='maxout'),main='Max outside')
   #tukey
   plotFunc(x,y,offsetXArgs=list(method='tukey'),main='Tukey')
   #beeswarm
